Stan Math Library: stan/math/fwd/core/operator_less_than_or_equal.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

operator_less_than_or_equal.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_CORE_OPERATOR_LESS_THAN_OR_EQUAL_HPP
2 #define STAN_MATH_FWD_CORE_OPERATOR_LESS_THAN_OR_EQUAL_HPP
3
4 #include <stan/math/fwd/core/fvar.hpp>
5
6
7 namespace stan {
8
9 namespace math {
10
11 template <typename T>
12 inline
13 bool
14 operator<=(const fvar<T>& x, const fvar<T>& y) {
15 return x.val_ <= y.val_;
16 }
17
18 template <typename T>
19 inline
20 bool
21 operator<=(const fvar<T>& x, double y) {
22 return x.val_ <= y;
23 }
24
25 template <typename T>
26 inline
27 bool
28 operator<=(double x, const fvar<T>& y) {
29 return x <= y.val_;
30 }
31 }
32 }
33 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
fvar.hpp
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.